@@ -17,77 +17,69 @@
 # You should have received a copy of the GNU General Public License
 # along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
-.setUp <- function(){
-	suppressMessages( require( inline ) )
-}
-
 test.List <- function(){
-	funx <- cfunction(signature(), '
+	funx <- cppfunction(signature(), '
 	List x(10) ;
 	for( int i=0; i<10; i++) x[i] = Rf_ScalarInteger( i * 2)  ;
-	return x ;', 
-		Rcpp=TRUE, verbose=FALSE, includes = "using namespace Rcpp;" )
+	return x ;')
 	checkEquals( funx(), as.list( 2*0:9), msg = "GenericVector" )
 }
 
 test.List.template <- function(){
-	funx <- cfunction(signature(), '
+	funx <- cppfunction(signature(), '
 	List x(4) ;
 	x[0] = "foo"  ;
 	x[1] = 10 ;
 	x[2] = 10.2 ;
 	x[3] = false; 
-	return x ;', 
-		Rcpp=TRUE, verbose=FALSE, includes = "using namespace Rcpp;" )
+	return x ;')
 	checkEquals( funx(), 
 		list( "foo", 10L, 10.2, FALSE), 
 		msg = "GenericVector" )
 }
 
 test.List.VECSXP <- function(){
-	funx <- cfunction(signature(vec = "list" ), '
+	funx <- cppfunction(signature(vec = "list" ), '
 	List x(vec) ;
-	return x ;', 
-		Rcpp=TRUE, verbose=FALSE, includes = "using namespace Rcpp;" )
+	return x ;' )
 	checkEquals( funx(list(1,2)), list(1,2), msg = "GenericVector( VECSXP) " )
 }
 
 test.List.initializer.list <- function(){
 	if( Rcpp:::capabilities()[["initializer lists"]] ){
-		funx <- cfunction(signature(), '
+		funx <- cppfunction(signature(), '
 		SEXP x0 = PROTECT( Rf_ScalarInteger( 0 ) ) ;
 		SEXP x1 = PROTECT( Rf_ScalarInteger( 1 ) ) ;
 		SEXP x2 = PROTECT( Rf_ScalarInteger( 2 ) ) ;
 		List x = { x0, x1, x2} ;
 		UNPROTECT(3) ;
-		return x ;', 
-			Rcpp=TRUE, verbose=FALSE, includes = "using namespace Rcpp;", cxxargs="-std=c++0x" )
+		return x ;', cxxargs="-std=c++0x" )
 		checkEquals( funx(), as.list(0:2), msg = "List( initializer list) " )
 	}
 }
 
 test.List.matrix.indexing <- function(){
 	
-	funx <- cfunction(signature(x = "character" ), '
+	funx <- cppfunction(signature(x = "character" ), '
 		GenericVector m(x) ;
 		GenericVector out(4) ;
 		for( size_t i=0 ; i<4; i++){
 			out[i] = m(i,i) ;
 		}
 		return out ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;"  )
+	'  )
 	
 	# a matrix of integer vectors
 	x <- structure( lapply( 1:16, function(x) seq.int(x) ), dim = c( 4, 4) )
 	checkEquals( funx(x), diag(x), msg = "matrix indexing" )
 	
-	funx <- cfunction(signature(x = "integer" ), '
+	funx <- cppfunction(signature(x = "integer" ), '
 		GenericVector m(x) ;
 		for( size_t i=0 ; i<4; i++){
 			m(i,i) = "foo" ;
 		}
 		return m ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;"  )
+	'  )
 	checkEquals( diag(funx(x)), rep(list("foo"), 4) , 
 		msg = "matrix indexing lhs" )
 	
@@ -98,23 +90,23 @@ test.List.matrix.indexing <- function(){
 
 test.List.Dimension.constructor <- function(){
 
-	funx <- cfunction(signature(), '
+	funx <- cppfunction(signature(), '
 		return List( Dimension( 5 ) ) ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;"  )
+	'  )
 	checkEquals( funx(), 
 		rep(list(NULL),5) , 
 		msg = "List( Dimension(5))" )
 	
-	funx <- cfunction(signature(), '
+	funx <- cppfunction(signature(), '
 		return List( Dimension( 5, 5 ) ) ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;"  )
+	'  )
 	checkEquals( funx(), 
 		structure( rep( list(NULL), 25), dim = c(5,5) ),
 		msg = "List( Dimension(5,5))" )
 	
-	funx <- cfunction(signature(), '
+	funx <- cppfunction(signature(), '
 		return List( Dimension( 2, 3, 4) ) ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;"  )
+	'  )
 	checkEquals( funx(), 
 		array( rep(list(NULL)), dim = c(2,3,4) ) , 
 		msg = "List( Dimension(2,3,4))" )
@@ -122,15 +114,14 @@ test.List.Dimension.constructor <- function(){
 
 test.List.iterator <- function(){
 	
-	cpp_lapply <- cfunction(signature(x = "list", g = "function" ), '
+	cpp_lapply <- cppfunction(signature(x = "list", g = "function" ), '
 		Function fun(g) ;
 		List input(x) ;
 		List output( input.size() ) ;
 		std::transform( input.begin(), input.end(), output.begin(), fun ) ;
 		output.names() = input.names() ;
 		return output ;
-	
-	', Rcpp = TRUE, includes = "using namespace Rcpp;"  )
+	'  )
 	
 	data <- list( x = letters, y = LETTERS, z = 1:4 )
 	checkEquals( 
@@ -142,26 +133,26 @@ test.List.iterator <- function(){
 
 test.List.name.indexing <- function(){
 	
-	funx <- cfunction( signature(x = "data.frame"), 
+	funx <- cppfunction( signature(x = "data.frame"), 
 	'
 	List df(x) ;
 	IntegerVector df_x = df["x"] ;
 	int res = std::accumulate( df_x.begin(), df_x.end(), 0 ) ;
 	return wrap(res);
-	', Rcpp = TRUE, includes = "using namespace Rcpp;" )
+	' )
 	d <- data.frame( x = 1:10, y = letters[1:10] )
 	checkEquals( funx( d ), sum(1:10), msg = "List names based indexing" )
 }
 
 test.List.push.back <- function(){
 	
-	funx <- cfunction( signature(x = "list"), 
+	funx <- cppfunction( signature(x = "list"), 
 	'
 	List list(x) ;
 	list.push_back( 10 ) ;
 	list.push_back( "bar", "foo" ) ;
 	return list ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;" )
+	' )
 	d <- list( x = 1:10, y = letters[1:10] )
 	res <- funx( d )
 	checkEquals( res,
@@ -171,13 +162,13 @@ test.List.push.back <- function(){
 
 test.List.push.front <- function(){
 	
-	funx <- cfunction( signature(x = "list"), 
+	funx <- cppfunction( signature(x = "list"), 
 	'
 	List list(x) ;
 	list.push_front( 10 ) ;
 	list.push_front( "bar", "foo" ) ;
 	return list ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;" )
+	' )
 	d <- list( x = 1:10, y = letters[1:10] )
 	res <- funx( d )
 	checkEquals( res,
@@ -187,13 +178,13 @@ test.List.push.front <- function(){
 
 # test.List.insert <- function(){
 # 	
-# 	funx <- cfunction( signature(x = "list"), 
+# 	funx <- cppfunction( signature(x = "list"), 
 # 	'
 # 	List list(x) ;
 # 	list.insert( list.begin(), 10 ) ;
 # 	list.insert( list.end(), Named("foo", "bar" ) ) ;
 # 	return list ;
-# 	', Rcpp = TRUE, includes = "using namespace Rcpp;" )
+# 	' )
 # 	d <- list( x = 1:10, y = letters[1:10] )
 # 	res <- funx( d )
 # 	checkEquals( res,
@@ -203,12 +194,12 @@ test.List.push.front <- function(){
 
 test.List.erase <- function(){
 	
-	funx <- cfunction( signature(x = "list"), 
+	funx <- cppfunction( signature(x = "list"), 
 	'
 	List list(x) ;
 	list.erase( list.begin() ) ;
 	return list ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;" )
+	' )
 	d <- list( x = 1:10, y = letters[1:10] )
 	res <- funx( d )
 	checkEquals( res,
@@ -218,12 +209,12 @@ test.List.erase <- function(){
 
 test.List.erase.range <- function(){
 	
-	funx <- cfunction( signature(x = "list"), 
+	funx <- cppfunction( signature(x = "list"), 
 	'
 	List list(x) ;
 	list.erase( 0, 1 ) ;
 	return list ;
-	', Rcpp = TRUE, includes = "using namespace Rcpp;" )
+	' )
 	d <- list( x = 1:10, y = letters[1:10], z = 1:10 )
 	res <- funx( d )
 	checkEquals( res,
@@ -233,13 +224,13 @@ test.List.erase.range <- function(){
 
 test.List.implicit.push.back <- function(){
 
-        funx <- cfunction( signature(),
+        funx <- cppfunction( signature(),
         '
         List list ;
         list["foo"] = 10 ;
         list["bar" ] = "foobar" ;
         return list ;
-        ', Rcpp = TRUE, includes = "using namespace Rcpp;" )
+        ' )
         checkEquals( funx(), list( foo = 10, bar = "foobar" ), msg = "List implicit push back" )
 }
 
