@@ -43,8 +43,8 @@ void logTxtFunction(const char* file, const int line, const char* expression) {
 }
 
 SEXP capabilities(){
-	SEXP cap = PROTECT( Rf_allocVector( LGLSXP, 6) ) ;
-	SEXP names = PROTECT( Rf_allocVector( STRSXP, 6 ) ) ;
+	SEXP cap = PROTECT( Rf_allocVector( LGLSXP, 7) ) ;
+	SEXP names = PROTECT( Rf_allocVector( STRSXP, 7 ) ) ;
 #ifdef HAS_VARIADIC_TEMPLATES
 	LOGICAL(cap)[0] = TRUE ;
 #else
@@ -76,12 +76,19 @@ SEXP capabilities(){
 	LOGICAL(cap)[5] = FALSE ;
 #endif
 
+#ifdef RCPP_HAS_DEMANGLING
+	LOGICAL(cap)[6] = TRUE ;
+#else
+	LOGICAL(cap)[6] = FALSE ;
+#endif
+
 	SET_STRING_ELT(names, 0, Rf_mkChar("variadic templates") ) ;
 	SET_STRING_ELT(names, 1, Rf_mkChar("initializer lists") ) ;
 	SET_STRING_ELT(names, 2, Rf_mkChar("exception handling") ) ;
 	SET_STRING_ELT(names, 3, Rf_mkChar("tr1 unordered maps") ) ;
 	SET_STRING_ELT(names, 4, Rf_mkChar("tr1 unordered sets") ) ;
 	SET_STRING_ELT(names, 5, Rf_mkChar("Rcpp modules") ) ;
+	SET_STRING_ELT(names, 6, Rf_mkChar("demangling") ) ;
 	Rf_setAttrib( cap, R_NamesSymbol, names ) ;
 	UNPROTECT(2) ;
 	return cap ;
